package de.intevation.gnv.math;

import com.vividsolutions.jts.geom.Coordinate;

/**
 * Implementations provides the ability to calculate the distance between
 * two points ans support for interpolating points between two points.
 *
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public interface Metrics
{
    /**
     * Calculates the distance between two given points.
     * @param p1 The first point.
     * @param p2 The second point.
     * @return The distance.
     */
    double distance(Coordinate p1, Coordinate p2);

    /**
     * Return an interpolator which allows interpolations between
     * two given points.
     * @param p1 The first point.
     * @param p2 The second point.
     * @return The interpolator.
     */
    Interpolator getInterpolator(Coordinate p1, Coordinate p2);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
